@@ -7,6 +7,7 @@ from sqlalchemy import (
     DateTime,
     ForeignKey,
     UniqueConstraint,
+    Boolean,
 )
 
 from ...database import Base
@@ -23,6 +24,7 @@ class InterventionNormModel(Base):
     )
     norm_cui = Column(String(50), nullable=False, index=True)
     norm_cui_name = Column(String(191), nullable=False)
+    is_deleted = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
